@@ -3,10 +3,7 @@
 #include "../nstd.h"
 #include <stddef.h>
 #include <stdint.h>
-#ifdef NSTDCPP
-extern "C"
-{
-#endif
+NSTDCPPSTART
 
 /// Represents a pointer to any type.
 typedef void *NSTDAny;
@@ -67,7 +64,14 @@ typedef enum
     NSTD_BOOL_TRUE
 } NSTDBool;
 
-#ifdef NSTDCPP
-}
-#endif
+/// The value of a single bit, either on or off.
+typedef enum
+{
+    /// The bit is off (0).
+    NSTD_BIT_VALUE_OFF,
+    /// The bit is on (1).
+    NSTD_BIT_VALUE_ON
+} NSTDBitValue;
+
+NSTDCPPEND
 #endif
