@@ -5,10 +5,7 @@
 #include "events.h"
 #include "image.h"
 #include "nstd.h"
-#ifdef NSTDCPP
-extern "C"
-{
-#endif
+NSTDCPPSTART
 
 /// Represents a window.
 typedef NSTDAny NSTDWindow;
@@ -218,7 +215,5 @@ NSTDAPI NSTDFloat64 nstd_gui_display_get_scale_factor(const NSTDDisplay display)
 ///     `NSTDDisplay *const display` - Pointer to the display handle.
 NSTDAPI void nstd_gui_display_free(NSTDDisplay *const display);
 
-#ifdef NSTDCPP
-}
-#endif
+NSTDCPPEND
 #endif
