@@ -1,3 +1,5 @@
+pub mod handle;
+use self::handle::NSTDOSWindowsIOHandle;
 use crate::{
     core::{
         def::{NSTDChar, NSTDErrorCode},
@@ -10,10 +12,8 @@ use windows_sys::Win32::{
     System::Console::{GetStdHandle, SetConsoleOutputCP, WriteConsoleA, STD_OUTPUT_HANDLE},
 };
 
-/// Represents a handle to a standard IO stream.
-pub type NSTDOSWindowsIOHandle = u32;
-
-/// Initializes the `nstd.os.windows.io` module. This function should be called before any others.
+/// Initializes the `nstd.os.windows.io` module. This function should be called before any others in
+/// this module.
 /// Returns: `NSTDErrorCode errc` - Nonzero on error.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
@@ -21,18 +21,6 @@ pub unsafe extern "C" fn nstd_os_windows_io_init() -> NSTDErrorCode {
     (SetConsoleOutputCP(CP_UTF8) == 0) as NSTDErrorCode
 }
 
-/// Gets the `NSTDOSWindowsHandle` of a `NSTDOSWindowsIOHandle`.
-/// Parameters:
-///     `const NSTDOSWindowsIOHandle stream` - An IO handle.
-/// Returns: `NSTDOSWindowsHandle handle` - The Window's handle.
-#[inline]
-#[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_os_windows_io_handle_as_handle(
-    stream: NSTDOSWindowsIOHandle,
-) -> NSTDOSWindowsHandle {
-    GetStdHandle(stream)
-}
-
 /// Writes a C string to stdout.
 /// Parameters:
 ///     `const NSTDChar *const cstr` - The C string to write to stdout.
@@ -68,7 +56,7 @@ pub unsafe extern "C" fn nstd_os_windows_io_stdout() -> NSTDOSWindowsIOHandle {
 
 /// Writes a buffer of `bytes` to `stream`.
 /// Parameters:
-///     `const NSTDOSWindowsHandle stream` - Handle to a standard IO stream.
+///     `const NSTDOSWindowsHandle stream` - Handle to an IO stream.
 ///     `const NSTDSlice *const bytes` - The bytes to write to the stream.
 ///     `NSTDUInt32 *const written` - Returns as the number of bytes actually written.
 /// Returns: `NSTDErrorCode errc` - Nonzero on error.
